@@ -7,7 +7,7 @@ def split_data(*args, **kwargs):
     `(X_train, y_train), (X_test, y_test)`, for a problem of type `task`.
 
     Julia Equivalent:
-    `IAI.split_data <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.split_data>`
+    `IAI.split_data <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.split_data>`
 
     Examples
     --------
@@ -20,7 +20,7 @@ def set_rich_output_param(*args, **kwargs):
     """Sets the global rich output parameter `key` to `value`.
 
     Julia Equivalent:
-    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.set_rich_output_param!>`
+    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.set_rich_output_param!>`
 
     Examples
     --------
@@ -33,7 +33,7 @@ def get_rich_output_params(*args, **kwargs):
     """Return the current global rich output parameter settings.
 
     Julia Equivalent:
-    `IAI.get_rich_output_params <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.get_rich_output_params>`
+    `IAI.get_rich_output_params <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_rich_output_params>`
 
     Examples
     --------
@@ -46,7 +46,7 @@ def delete_rich_output_param(*args, **kwargs):
     """Delete the global rich output parameter `key`.
 
     Julia Equivalent:
-    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
+    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
 
     Examples
     --------
@@ -70,7 +70,7 @@ class Learner():
         """Fit a model using the parameters in learner and the data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.fit! <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.fit!>`
+        `IAI.fit! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.fit!>`
 
         Examples
         --------
@@ -79,7 +79,7 @@ class Learner():
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v1.2.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_convert(self._jl_obj, *args, **kwargs)
@@ -89,7 +89,7 @@ class Learner():
         """Write learner or grid to `filename` in JSON format.
 
         Julia Equivalent:
-        `IAI.write_json <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.write_json>`
+        `IAI.write_json <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.write_json>`
 
         Examples
         --------
@@ -104,7 +104,7 @@ class Learner():
         """Return the value of all learner parameters.
 
         Julia Equivalent:
-        `IAI.get_params <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.get_params>`
+        `IAI.get_params <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_params>`
 
         Examples
         --------
@@ -119,7 +119,7 @@ class Learner():
         """Set all supplied parameters on learner.
 
         Julia Equivalent:
-        `IAI.set_params! <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.set_params!>`
+        `IAI.set_params! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.set_params!>`
 
         Examples
         --------
@@ -135,7 +135,7 @@ class Learner():
         """Return an unfitted copy of the learner with the same parameters.
 
         Julia Equivalent:
-        `IAI.clone <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.clone>`
+        `IAI.clone <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.clone>`
 
         Examples
         --------
@@ -159,7 +159,7 @@ class SupervisedLearner(Learner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.predict>`
+        `IAI.predict <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict>`
 
         Examples
         --------
@@ -171,7 +171,7 @@ class SupervisedLearner(Learner):
         """Calculates the score for the learner on data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.score>`
+        `IAI.score <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.score>`
 
         Examples
         --------
@@ -179,6 +179,20 @@ class SupervisedLearner(Learner):
         """
         return _IAI.score_convert(self._jl_obj, *args, **kwargs)
 
+    def variable_importance(self):
+        """Generate a ranking of the variables in the learner according to
+        their importance during training. The results are normalized so that
+        they sum to one.
+
+        Julia Equivalent:
+        `IAI.variable_importance <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.variable_importance>`
+
+        Examples
+        --------
+        >>> lnr.variable_importance()
+        """
+        return _IAI.variable_importance_convert(self._jl_obj)
+
 
 class UnsupervisedLearner(Learner):
     """Abstract type encompassing all learners for unsupervised tasks"""
@@ -193,7 +207,7 @@ class ClassificationLearner(SupervisedLearner):
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_proba <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.predict_proba>`
+        `IAI.predict_proba <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_proba>`
 
         Examples
         --------
@@ -219,7 +233,7 @@ class SurvivalLearner(SupervisedLearner):
         each point in the data `X`.
 
         Julia Equivalent:
-        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
 
         Examples
         --------
@@ -241,7 +255,7 @@ class SurvivalLearner(SupervisedLearner):
         survival time.
 
         Julia Equivalent:
-        `IAI.predict_hazard <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.predict_hazard>`
+        `IAI.predict_hazard <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_hazard>`
 
         Examples
         --------
@@ -263,7 +277,7 @@ class PrescriptionLearner(SupervisedLearner):
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.predict_outcomes>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D>`
 
         Examples
         --------
@@ -272,11 +286,33 @@ class PrescriptionLearner(SupervisedLearner):
         return _IAI.predict_outcomes_convert(self._jl_obj, *args, **kwargs)
 
 
+class PolicyLearner(SupervisedLearner):
+    """Abstract type encompassing all learners for policy tasks"""
+
+    def predict_outcomes(self, *args, **kwargs):
+        """Return the outcome from `rewards` for point in the features `X`
+        under the prescriptions made by the learner.
+
+        Julia Equivalent:
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_outcomes-Union%7BTuple%7BO%7D%2C%2520Tuple%7BLearner%7BIAIBase.PolicyTask%7BO%7D%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D%7D%2520where%2520O>`
+
+        Examples
+        --------
+        >>> lnr.predict_outcomes(X, rewards)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.0 or higher.
+        """
+        _requires_iai_version("2.0.0", "predict_outcomes")
+        return _IAI.predict_outcomes_convert(self._jl_obj, *args, **kwargs)
+
+
 class GridSearch(Learner):
     """Controls grid search over parameter combinations in `params` for `lnr`.
 
     Julia Equivalent:
-    `IAI.GridSearch <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.GridSearch>`
+    `IAI.GridSearch <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.GridSearch>`
 
     Examples
     --------
@@ -349,7 +385,7 @@ class GridSearch(Learner):
         the grid.
 
         Julia Equivalent:
-        `IAI.get_learner <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.get_learner>`
+        `IAI.get_learner <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_learner>`
 
         Examples
         --------
@@ -364,7 +400,7 @@ class GridSearch(Learner):
         """Return the best parameter combination from the grid.
 
         Julia Equivalent:
-        `IAI.get_best_params <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.get_best_params>`
+        `IAI.get_best_params <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_best_params>`
 
         Examples
         --------
@@ -376,7 +412,7 @@ class GridSearch(Learner):
         """Return a summary of the results from the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_results <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.get_grid_results>`
+        `IAI.get_grid_results <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_grid_results>`
 
         Examples
         --------
@@ -388,7 +424,7 @@ class GridSearch(Learner):
         """Fit a grid with data `X` and `y` using k-fold cross-validation.
 
         Julia Equivalent:
-        `IAI.fit_cv! <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.fit_cv!>`
+        `IAI.fit_cv! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.fit_cv!>`
 
         Examples
         --------
@@ -397,7 +433,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v1.2.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_cv_convert(self._jl_obj, *args, **kwargs)
@@ -408,7 +444,7 @@ class GridSearch(Learner):
         cross-validation and impute missing values in `X`.
 
         Julia Equivalent:
-        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.fit_transform_cv!>`
+        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.fit_transform_cv!>`
 
         Examples
         --------
@@ -417,7 +453,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v1.2.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         # TODO is this the best way to do it? Some way of adding the task mixin
@@ -438,18 +474,18 @@ class ROCCurve():
     - `auc`: the area-under-the-curve (AUC)
 
     Julia Equivalent:
-    `IAI.ROCCurve <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.ROCCurve>`
+    `IAI.ROCCurve <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.ROCCurve>`
 
     Examples
     --------
     Construct an
-    `ROCCurve <https://docs.interpretable.ai/v1.2.0/IAI-Python/reference/#ROCCurve>`
+    `ROCCurve <https://docs.interpretable.ai/v2.0.0/IAI-Python/reference/#ROCCurve>`
     using trained `lnr` on the features `X` and labels `y`:
 
     >>> ROCCurve(lnr, X, y)
 
     Construct an
-    `ROCCurve <https://docs.interpretable.ai/v1.2.0/IAI-Python/reference/#ROCCurve>`
+    `ROCCurve <https://docs.interpretable.ai/v2.0.0/IAI-Python/reference/#ROCCurve>`
     using predicted probabilities `probs` and true labels `y`, with
     probabilities indicating chance of predicting `positive_label`:
 
@@ -482,7 +518,7 @@ class ROCCurve():
         """Visualize the ROC curve in the browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -498,7 +534,7 @@ class SurvivalCurve():
     time `t`.
 
     Julia Equivalent:
-    `IAI.SurvivalCurve <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.SurvivalCurve>`
+    `IAI.SurvivalCurve <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.SurvivalCurve>`
     """
     def __init__(self, jl_curve):
         self._jl_obj = jl_curve
@@ -517,7 +553,7 @@ class SurvivalCurve():
         - `'coefs'`: the probablility for each breakpoint on the curve
 
         Julia Equivalent:
-        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v1.2.0/IAIBase/reference/#IAI.get_survival_curve_data>`
+        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_survival_curve_data>`
 
         Examples
         --------
