@@ -1,7 +1,7 @@
 from .iai import _IAI, _requires_iai_version
 from .iaibase import (SupervisedLearner, ClassificationLearner,
                       RegressionLearner, SurvivalLearner, PrescriptionLearner,
-                      SurvivalCurve)
+                      PolicyLearner, SurvivalCurve)
 
 
 class TreeLearner(SupervisedLearner):
@@ -11,7 +11,7 @@ class TreeLearner(SupervisedLearner):
         """Return the number of nodes in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_nodes <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_num_nodes>`
+        `IAI.get_num_nodes <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_num_nodes>`
 
         Examples
         --------
@@ -23,7 +23,7 @@ class TreeLearner(SupervisedLearner):
         """Return `True` if node `node_index` in the trained learner is a leaf.
 
         Julia Equivalent:
-        `IAI.is_leaf <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_leaf>`
+        `IAI.is_leaf <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_leaf>`
 
         Examples
         --------
@@ -35,7 +35,7 @@ class TreeLearner(SupervisedLearner):
         """Return the depth of node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_depth <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_depth>`
+        `IAI.get_depth <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_depth>`
 
         Examples
         --------
@@ -48,7 +48,7 @@ class TreeLearner(SupervisedLearner):
         in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_samples <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_num_samples>`
+        `IAI.get_num_samples <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_num_samples>`
 
         Examples
         --------
@@ -61,7 +61,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_lower_child <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_lower_child>`
+        `IAI.get_lower_child <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_lower_child>`
 
         Examples
         --------
@@ -74,7 +74,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_parent <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_parent>`
+        `IAI.get_parent <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_parent>`
 
         Examples
         --------
@@ -87,7 +87,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_upper_child <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_upper_child>`
+        `IAI.get_upper_child <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_upper_child>`
 
         Examples
         --------
@@ -100,7 +100,7 @@ class TreeLearner(SupervisedLearner):
         parallel split.
 
         Julia Equivalent:
-        `IAI.is_parallel_split <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_parallel_split>`
+        `IAI.is_parallel_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_parallel_split>`
 
         Examples
         --------
@@ -113,7 +113,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split.
 
         Julia Equivalent:
-        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_hyperplane_split>`
+        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_hyperplane_split>`
 
         Examples
         --------
@@ -126,7 +126,7 @@ class TreeLearner(SupervisedLearner):
         categoric split.
 
         Julia Equivalent:
-        `IAI.is_categoric_split <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_categoric_split>`
+        `IAI.is_categoric_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_categoric_split>`
 
         Examples
         --------
@@ -139,7 +139,7 @@ class TreeLearner(SupervisedLearner):
         ordinal split.
 
         Julia Equivalent:
-        `IAI.is_ordinal_split <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_ordinal_split>`
+        `IAI.is_ordinal_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_ordinal_split>`
 
         Examples
         --------
@@ -152,7 +152,7 @@ class TreeLearner(SupervisedLearner):
         categoric/parallel split.
 
         Julia Equivalent:
-        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
+        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
 
         Examples
         --------
@@ -165,7 +165,7 @@ class TreeLearner(SupervisedLearner):
         categoric/ordinal split.
 
         Julia Equivalent:
-        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
+        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
 
         Examples
         --------
@@ -178,7 +178,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.missing_goes_lower <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.missing_goes_lower>`
+        `IAI.missing_goes_lower <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.missing_goes_lower>`
 
         Examples
         --------
@@ -191,7 +191,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_feature <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_split_feature>`
+        `IAI.get_split_feature <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_feature>`
 
         Examples
         --------
@@ -204,7 +204,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_threshold <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_split_threshold>`
+        `IAI.get_split_threshold <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_threshold>`
 
         Examples
         --------
@@ -217,7 +217,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_categories <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_split_categories>`
+        `IAI.get_split_categories <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_categories>`
 
         Examples
         --------
@@ -230,7 +230,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split at  node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_weights <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_split_weights>`
+        `IAI.get_split_weights <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_weights>`
 
         Examples
         --------
@@ -243,7 +243,7 @@ class TreeLearner(SupervisedLearner):
         features `X` falls.
 
         Julia Equivalent:
-        `IAI.apply <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.apply>`
+        `IAI.apply <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.apply>`
 
         Examples
         --------
@@ -256,7 +256,7 @@ class TreeLearner(SupervisedLearner):
         each node in the learner.
 
         Julia Equivalent:
-        `IAI.apply_nodes <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.apply_nodes>`
+        `IAI.apply_nodes <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.apply_nodes>`
 
         Examples
         --------
@@ -269,7 +269,7 @@ class TreeLearner(SupervisedLearner):
         the features `X` passes through the `j`th node in the learner.
 
         Julia Equivalent:
-        `IAI.decision_path <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.decision_path>`
+        `IAI.decision_path <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.decision_path>`
 
         Examples
         --------
@@ -282,7 +282,7 @@ class TreeLearner(SupervisedLearner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.print_path <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.print_path>`
+        `IAI.print_path <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.print_path>`
 
         Examples
         --------
@@ -290,18 +290,6 @@ class TreeLearner(SupervisedLearner):
         """
         return _IAI.print_path_convert(self._jl_obj, *args, **kwargs)
 
-    def variable_importance(self):
-        """Generate a ranking of the variables in the learner according to their importance when training the trees.
-
-        Julia Equivalent:
-        `IAI.variable_importance <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.variable_importance>`
-
-        Examples
-        --------
-        >>> lnr.variable_importance()
-        """
-        return _IAI.variable_importance_convert(self._jl_obj)
-
     def write_png(self, filename, **kwargs):  # pragma: no cover
         """Write learner to `filename` as a PNG image.
 
@@ -310,7 +298,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_png <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.write_png>`
+        `IAI.write_png <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_png>`
 
         Examples
         --------
@@ -323,7 +311,7 @@ class TreeLearner(SupervisedLearner):
         [.dot format](http://www.graphviz.org/content/dot-language/).
 
         Julia Equivalent:
-        `IAI.write_dot <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.write_dot>`
+        `IAI.write_dot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_dot>`
 
         Examples
         --------
@@ -336,7 +324,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -348,7 +336,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive visualization of learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -361,7 +349,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_questionnaire <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.write_questionnaire>`
+        `IAI.write_questionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_questionnaire>`
 
         Examples
         --------
@@ -374,7 +362,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive questionnaire based on learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_questionnaire <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.show_questionnaire>`
+        `IAI.show_questionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.show_questionnaire>`
 
         Examples
         --------
@@ -393,7 +381,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         learner.
 
         Julia Equivalent:
-        `IAI.get_classification_label <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_classification_label>`
+        `IAI.get_classification_label <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_classification_label>`
 
         Examples
         --------
@@ -406,7 +394,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_classification_proba <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_classification_proba>`
+        `IAI.get_classification_proba <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_classification_proba>`
 
         Examples
         --------
@@ -421,7 +409,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         will be simplified after all changes have been made.
 
         Julia Equivalent:
-        `IAI.set_threshold! <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.set_threshold!>`
+        `IAI.set_threshold! <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.set_threshold!>`
 
         Examples
         --------
@@ -434,7 +422,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         """Show the probability of `display_label` when visualizing learner.
 
         Julia Equivalent:
-        `IAI.set_display_label! <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.set_display_label!>`
+        `IAI.set_display_label! <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.set_display_label!>`
 
         Examples
         --------
@@ -448,7 +436,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         predicted label when visualizing learner.
 
         Julia Equivalent:
-        `IAI.reset_display_label! <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.reset_display_label!>`
+        `IAI.reset_display_label! <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.reset_display_label!>`
 
         Examples
         --------
@@ -468,7 +456,7 @@ class RegressionTreeLearner(RegressionLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -481,7 +469,7 @@ class RegressionTreeLearner(RegressionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -496,11 +484,11 @@ class SurvivalTreeLearner(SurvivalLearner):
 
     def get_survival_curve(self, node_index):
         """Return the
-        `SurvivalCurve <https://docs.interpretable.ai/v1.2.0/IAI-Python/reference/#SurvivalCurve>`
+        `SurvivalCurve <https://docs.interpretable.ai/v2.0.0/IAI-Python/reference/#SurvivalCurve>`
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_curve <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_survival_curve>`
+        `IAI.get_survival_curve <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_survival_curve>`
 
         Examples
         --------
@@ -520,7 +508,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
+        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
 
         Examples
         --------
@@ -534,7 +522,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
@@ -548,7 +536,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         `treatment` at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
@@ -558,6 +546,29 @@ class PrescriptionTreeLearner(PrescriptionLearner):
                                                    treatment)
 
 
+class PolicyTreeLearner(PolicyLearner):
+    """Abstract type encompassing all tree-based learners with policy leaves.
+    """
+
+    def get_policy_treatment_rank(self, node_index):
+        """Return the treatments ordered from most effective to least effective
+        at node `node_index` in the trained learner.
+
+        Julia Equivalent:
+        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
+
+        Examples
+        --------
+        >>> lnr.get_policy_treatment_rank(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.0 or higher.
+        """
+        _requires_iai_version("2.0.0", "get_policy_treatment_rank")
+        return _IAI.get_policy_treatment_rank_convert(self._jl_obj, node_index)
+
+
 class AbstractVisualization():
     """Abstract type encompassing objects related to visualization. """
     def __init__(self, jl_obj):
@@ -573,7 +584,7 @@ class AbstractVisualization():
         """Write interactive browser visualization to `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -585,7 +596,7 @@ class AbstractVisualization():
         """Show interactive visualization in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -598,7 +609,7 @@ class TreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of `lnr`.
 
     Julia Equivalent:
-    `IAI.TreePlot <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.TreePlot>`
+    `IAI.TreePlot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.TreePlot>`
 
     Examples
     --------
@@ -607,7 +618,7 @@ class TreePlot(AbstractVisualization):
     Parameters
     ----------
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v1.2.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -624,7 +635,7 @@ class Questionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of `lnr`.
 
     Julia Equivalent:
-    `IAI.Questionnaire <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.Questionnaire>`
+    `IAI.Questionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.Questionnaire>`
 
     Examples
     --------
@@ -634,7 +645,7 @@ class Questionnaire(AbstractVisualization):
     ----------
 
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v1.2.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -652,7 +663,7 @@ class MultiQuestionnaire(AbstractVisualization):
     specified by `questions`
 
     Julia Equivalent:
-    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
+    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
 
     Examples
     --------
@@ -661,7 +672,7 @@ class MultiQuestionnaire(AbstractVisualization):
     Parameters
     ----------
     The questions to visualize. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v1.2.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     Compatibility
@@ -679,7 +690,7 @@ class MultiTreePlot(AbstractVisualization):
     specified by `questions`
 
     Julia Equivalent:
-    `IAI.MultiTreePlot <https://docs.interpretable.ai/v1.2.0/IAITrees/reference/#IAI.MultiTreePlot>`
+    `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.MultiTreePlot>`
 
     Examples
     --------
@@ -688,7 +699,7 @@ class MultiTreePlot(AbstractVisualization):
     Parameters
     ----------
     The questions to visualize. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v1.2.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     Compatibility
