@@ -1,7 +1,8 @@
-from .iai import _IAI
+from .iai import _IAI, _iai_version_less_than, _requires_iai_version
 from .iaitrees import (TreeLearner, ClassificationTreeLearner,
                        RegressionTreeLearner, SurvivalTreeLearner,
-                       PrescriptionTreeLearner)
+                       PrescriptionTreeLearner, PolicyTreeLearner)
+import warnings as _warnings
 
 
 class OptimalTreeLearner(TreeLearner):
@@ -13,7 +14,7 @@ class OptimalTreeClassifier(OptimalTreeLearner, ClassificationTreeLearner):
     """Learner for training Optimal Classification Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeClassifier <https://docs.interpretable.ai/v1.2.0/OptimalTrees/reference/#IAI.OptimalTreeClassifier>`
+    `IAI.OptimalTreeClassifier <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreeClassifier>`
 
     Examples
     --------
@@ -33,7 +34,7 @@ class OptimalTreeRegressor(OptimalTreeLearner, RegressionTreeLearner):
     """Learner for training Optimal Regression Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeRegressor <https://docs.interpretable.ai/v1.2.0/OptimalTrees/reference/#IAI.OptimalTreeRegressor>`
+    `IAI.OptimalTreeRegressor <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreeRegressor>`
 
     Examples
     --------
@@ -49,15 +50,15 @@ class OptimalTreeRegressor(OptimalTreeLearner, RegressionTreeLearner):
         super().__init__(jl_obj)
 
 
-class OptimalTreeSurvivor(OptimalTreeLearner, SurvivalTreeLearner):
+class OptimalTreeSurvivalLearner(OptimalTreeLearner, SurvivalTreeLearner):
     """Learner for training Optimal Survival Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeSurvivor <https://docs.interpretable.ai/v1.2.0/OptimalTrees/reference/#IAI.OptimalTreeSurvivor>`
+    `IAI.OptimalTreeSurvivalLearner <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreeSurvivalLearner>`
 
     Examples
     --------
-    >>> OptimalTreeSurvivor(**kwargs)
+    >>> OptimalTreeSurvivalLearner(**kwargs)
 
     Parameters
     ----------
@@ -65,17 +66,36 @@ class OptimalTreeSurvivor(OptimalTreeLearner, SurvivalTreeLearner):
     the Julia documentation for available parameters.
     """
     def __init__(self, *args, **kwargs):
-        jl_obj = _IAI.OptimalTreeSurvivor_convert(*args, **kwargs)
+        if _iai_version_less_than("2.0.0"):
+            jl_obj = _IAI.OptimalTreeSurvivor_convert(*args, **kwargs)
+        else:
+            jl_obj = _IAI.OptimalTreeSurvivalLearner_convert(*args, **kwargs)
         super().__init__(jl_obj)
 
 
+class OptimalTreeSurvivor(OptimalTreeSurvivalLearner):
+    """Learner for training Optimal Survival Trees.
+
+    This class was deprecated and renamed to OptimalTreeSurvivalLearner in
+    interpretableai 2.0.2. This is for consistency with the IAI v2.0.0 Julia
+    release.
+    """
+    def __init__(self, *args, **kwargs):
+        _warnings.warn(
+            "'OptimalTreeSurvivor' is deprecated, use " +
+            "'OptimalTreeSurvivalLearner'",
+            FutureWarning
+        )
+        super().__init__(*args, **kwargs)
+
+
 class OptimalTreePrescriptionMinimizer(OptimalTreeLearner,
                                        PrescriptionTreeLearner):
     """Learner for training Optimal Prescriptive Trees where the prescriptions
     should aim to minimize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePrescriptionMinimizer <https://docs.interpretable.ai/v1.2.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMinimizer>`
+    `IAI.OptimalTreePrescriptionMinimizer <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMinimizer>`
 
     Examples
     --------
@@ -97,7 +117,7 @@ class OptimalTreePrescriptionMaximizer(OptimalTreeLearner,
     should aim to maximize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePrescriptionMaximizer <https://docs.interpretable.ai/v1.2.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMaximizer>`
+    `IAI.OptimalTreePrescriptionMaximizer <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMaximizer>`
 
     Examples
     --------
@@ -111,3 +131,55 @@ class OptimalTreePrescriptionMaximizer(OptimalTreeLearner,
     def __init__(self, *args, **kwargs):
         jl_obj = _IAI.OptimalTreePrescriptionMaximizer_convert(*args, **kwargs)
         super().__init__(jl_obj)
+
+
+class OptimalTreePolicyMinimizer(OptimalTreeLearner, PolicyTreeLearner):
+    """Learner for training Optimal Policy Trees where the policy
+    should aim to minimize outcomes.
+
+    Julia Equivalent:
+    `IAI.OptimalTreePolicyMinimizer <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMinimizer>`
+
+    Examples
+    --------
+    >>> OptimalTreePolicyMinimizer(**kwargs)
+
+    Parameters
+    ----------
+    Use keyword arguments to set parameters on the resulting learner. Refer to
+    the Julia documentation for available parameters.
+
+    Compatibility
+    -------------
+    Requires IAI version 2.0 or higher.
+    """
+    def __init__(self, *args, **kwargs):
+        _requires_iai_version("2.0.0", "OptimalTreePolicyMinimizer")
+        jl_obj = _IAI.OptimalTreePolicyMinimizer_convert(*args, **kwargs)
+        super().__init__(jl_obj)
+
+
+class OptimalTreePolicyMaximizer(OptimalTreeLearner, PolicyTreeLearner):
+    """Learner for training Optimal Policy Trees where the policy
+    should aim to maximize outcomes.
+
+    Julia Equivalent:
+    `IAI.OptimalTreePolicyMaximizer <https://docs.interpretable.ai/v2.0.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMaximizer>`
+
+    Examples
+    --------
+    >>> OptimalTreePolicyMaximizer(**kwargs)
+
+    Parameters
+    ----------
+    Use keyword arguments to set parameters on the resulting learner. Refer to
+    the Julia documentation for available parameters.
+
+    Compatibility
+    -------------
+    Requires IAI version 2.0 or higher.
+    """
+    def __init__(self, *args, **kwargs):
+        _requires_iai_version("2.0.0", "OptimalTreePolicyMaximizer")
+        jl_obj = _IAI.OptimalTreePolicyMaximizer_convert(*args, **kwargs)
+        super().__init__(jl_obj)
